@@ -4,6 +4,7 @@ import os
 import binascii
 import hashlib
 import oz.app
+from tornado import escape
 
 from .middleware import *
 from .options import *
@@ -11,10 +12,10 @@ from .tests import *
 
 def random_hex(length):
     """Generates a random hex string"""
-    return binascii.hexlify(os.urandom(length))[length:]
+    return escape.to_unicode(binascii.hexlify(os.urandom(length))[length:])
 
 def password_hash(password, password_salt=None):
     """Hashes a specified password"""
     password_salt = password_salt or oz.app.settings["session_salt"]
-    salted_password = "".join([unicode(password_salt), password])
-    return "sha256!%s" % unicode(hashlib.sha256(salted_password.encode("utf-8")).hexdigest())
+    salted_password = password_salt + password
+    return "sha256!%s" % hashlib.sha256(salted_password.encode("utf-8")).hexdigest()
